@@ -1,7 +1,9 @@
+require 'active_support/core_ext/class/attribute'
+
 module RablRails
   module Handlers
     class Rabl
-      cattr_accessor :default_format
+      class_attribute :default_format
       self.default_format = 'application/json'
 
       def self.call(template)
